camelot.camelot.view.controls.editors.Many2OneEditor

Package camelot :: Package camelot :: Package view :: Package controls :: Module editors :: Class Many2OneEditor |
[hide private]
[frames] | no frames]

# Class Many2OneEditor

source code

Widget for editing many 2 one relations

Nested Classes | [hide private]
| CompletionsModel

Instance Methods | [hide private]
__init__(self, entity_admin=None, parent=None) | source code
textEdited(self, text) | source code
search_completions(self, text) Search for object that match text, to fill the list of completions | source code
display_search_completions(self, completions) | source code
completionActivated(self, index) | source code
openButtonClicked(self) | source code
returnPressed(self) | source code
searchButtonClicked(self) | source code
trashButtonClicked(self) | source code
createNew(self) | source code
createFormView(self) | source code
editingFinished(self) | source code
setEntity(self, entity_instance_getter, propagate=True) | source code
createSelectView(self) | source code
selectEntity(self, entity_instance_getter) | source code

Method Details | [hide private]

### __init__(self, entity_admin=None, parent=None) (Constructor) | source code
Parameters: `entity_admin` - The Admin interface for the object on the one side of the relation

### search_completions(self, text) | source code
Search for object that match text, to fill the list of completions Returns: a list of tuples of (object_representation, object_getter) Decorators: `@model_function`

### display_search_completions(self, completions) | source code
Decorators: `@gui_function`